<?php

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

/**
 * Déclaration des informations tierces (alias, traitements, jointures, etc)
 * sur les tables de la base de données modifiées ou ajoutées par le plugin.
 *
 * Le plugin se contente de déclarer les alias des tables et quelques traitements.
 *
 * @pipeline declarer_tables_interfaces
 *
 * @param array $interfaces Tableau global des informations tierces sur les tables de la base de données
 *
 * @return array Tableau fourni en entrée et mis à jour avec les nouvelles informations
 */
function rainette_histo_declarer_tables_interfaces(array $interfaces) : array {
	// Les tables : permet d'appeler une boucle avec le *type* de la table uniquement
	$interfaces['table_des_tables']['rainette_historiques'] = 'rainette_historiques';

	return $interfaces;
}

/**
 * Déclaration des nouvelles tables de la base de données propres au plugin.
 * Le plugin déclare une nouvelle table:
 * - `spip_rainette_historiques`, qui contient les enregistrements des données météo temps réel des lieux choisis.
 *
 * @pipeline declarer_tables_principales
 *
 * @param array $tables Tableau global décrivant la structure des tables de la base de données
 *
 * @return array Tableau fourni en entrée et mis à jour avec les nouvelles déclarations
 */
function rainette_histo_declarer_tables_principales(array $tables) : array {
	// Table spip_rainette_historiques
	// -- les champs de données utilisent le nom standard du mashup Rainette
	$table = [
		'histo_id' => "varchar(64) DEFAULT '' NOT NULL",                 // Identifiant unique de l'historisation
		'date'     => "datetime DEFAULT '0000-00-00 00:00:00' NOT NULL", // Datetime des données issu du flux
		'unite'    => "varchar(1) DEFAULT 'm' NOT NULL",                 // Identifiant du système d'unité utilisé par les données
	];

	// Acquérir les modes historisables et la liste des données historisées pour chacun des modes
	include_spip('inc/config');
	$config_rainette = lire_config('rainette_config', []);

	// Compléter la liste des champs historisés
	foreach ($config_rainette['historiques']['modes'] as $_mode) {
		foreach ($config_rainette[$_mode]['donnees'] as $_donnee => $_config) {
			if (!empty($_config['historisable'])) {
				$table[$_donnee] = $_config['type_php'];
			}
		}
	}

	$table_cles = [
		'PRIMARY KEY' => 'histo_id,date',
		'KEY unite'   => 'unite'
	];

	$tables['spip_rainette_historiques'] = [
		'field' => &$table,
		'key'   => &$table_cles,
	];

	return $tables;
}
