<?php

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

/**
 * Permet de conclure le chargement des données météo par des traitements divers.
 * Dans le cas de ce plugin, les données sont historisées en base et renvoyées sans modification.
 *
 * @pipeline post_chargement_meteo
 *
 * @param array $flux Tableau des données météo et des arguments de contexte
 *
 * @return array Tableau non modifié.
 */
function rainette_histo_post_chargement_meteo(array $flux) : array {
	// Avant de faire un quelconque traitement, on écarte le maximum de cas inutiles :
	// -> On exclut les modes non historisables et le tableau des données doit être rempli correctement
	include_spip('inc/config');
	if (
		($mode = $flux['args']['mode'])
		and ($config_rainette = lire_config('rainette_config', []))
		and in_array($mode, $config_rainette['historiques']['modes'])
		and $flux['data']['donnees']
	) {
		// Extraction des informations de contexte
		$service = $flux['args']['service'];
		$lieu_id = $flux['args']['lieu']['id'];
		$via_job = $flux['args']['via_job'];
		$unite = $flux['args']['configuration']['unite'];

		// Vérifier si le lieu et le mode sont bien à historiser.
		// -- pour cela on remonte à partir du mode et du contexte du fournisseur de données (service, lieu, job)
		//    vers le nom "humain" du lieu.
		//    L'historisation doit être active
		$histo_id = '';
		foreach (lire_config('rainette_historisations', []) as $_histo_id => $_historisation) {
			if (
				$_historisation['active']
				and ($_historisation['mode'] === $mode)
				and ($_historisation['service'] === $service)
				and ($_historisation['lieu_id'] === $lieu_id)
				and ($_historisation['via_job'] === $via_job)
			) {
				$histo_id = $_histo_id;
			}
		}

		// Si le lieu est bien historisé pour le mode concerné, on continue le traitement
		if ($histo_id) {
			// Extraction de la date de mise à jour des données (date du service) et normalisation de cette date
			// pour éviter d'avoir des enregistrements trop nombreux pour une même plage horaire :
			// -- on choisit de n'avoir pas plus d'un historique par heure
			$date = $flux['data']['donnees']['derniere_maj'];
			$date = date('Y-m-d H:00:00', strtotime($date));

			// Vérifier si l'enregistrement n'existe pas déjà
			$where = [
				'histo_id=' . sql_quote($histo_id),
				'date=' . sql_quote($date)
			];
			if (!sql_countsel('spip_rainette_historiques', $where)) {
				// On peut ajouter le nouvel enregistrement
				// -- la clé primaire
				// -- on loge l'unité utilisée (métrique ou impériale) ce qui permet d'assurer la continuité des historiques
				//    même si l'unité change
				$set = [
					'histo_id' => $histo_id,
					'date'     => $date,
					'unite'    => $unite,
				];

				// Acquérir la liste des données d'observations temps réel pour en extraire les seules données historisables
				$config_histo = $config_rainette[$mode]['donnees'] ?? [];

				// On boucle sur les données historisables et on les insère dans le tableau de mise à jour si non nulles
				foreach ($config_histo as $_donnee => $_config) {
					if (
						!empty($_config['historisable'])
						and (null !== $flux['data']['donnees'][$_donnee])
					) {
						$set[$_donnee] = $flux['data']['donnees'][$_donnee];
					}
				}

				sql_insertq('spip_rainette_historiques', $set);
			}
		}
	}

	return $flux;
}
